@@ -17,7 +17,10 @@ my $prebuilt_binaries = [
     {
       title    => "Binaries Win/32bit SDL-1.2.14 (extended, 20100328) RECOMMENDED\n" .
                   "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
-      url      => 'http://strawberryperl.com/package/kmx/sdl/Win32_SDL-1.2.14-extended-bin_20100328.zip',
+      url      => [
+        'http://strawberryperl.com/package/kmx/sdl/Win32_SDL-1.2.14-extended-bin_20100328.zip',
+        'http://froggs.de/libsdl/Win32_SDL-1.2.14-extended-bin_20100328.zip',
+      ],
       sha1sum  => 'a8f1c97ba5ec7184e3255921517bdf0e7397b56a',
       arch_re  => qr/^MSWin32-x86-multi-thread$/,
       os_re    => qr/^MSWin32$/,
@@ -26,7 +29,10 @@ my $prebuilt_binaries = [
     {
       title    => "Binaries Win/32bit SDL-1.2.14 (20090831)\n" .
                   "\t(gfx, image, mixer, net, smpeg, ttf)",
-      url      => 'http://strawberryperl.com/package/kmx/sdl/lib-SDL-bin_win32_v2.zip',
+      url      => [
+        'http://strawberryperl.com/package/kmx/sdl/lib-SDL-bin_win32_v2.zip',
+        'http://froggs.de/libsdl/lib-SDL-bin_win32_v2.zip',
+      ],
       sha1sum  => 'eaeeb96b0115462f6736de568de8ec233a2397a5',
       arch_re  => qr/^MSWin32-x86-multi-thread$/,
       os_re    => qr/^MSWin32$/,
@@ -35,7 +41,10 @@ my $prebuilt_binaries = [
     {
       title    => "Binaries Win/64bit SDL-1.2.14 (experimental, 20100301)\n" .
                   "\t(gfx, image, mixer, net, smpeg, ttf, sound, svg, rtf, Pango)",
-      url      => 'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20100301.zip',
+      url      => [
+        'http://strawberryperl.com/package/kmx/sdl/Win64_SDL-1.2.14-extended-bin_20100301.zip',
+        'http://froggs.de/libsdl/Win64_SDL-1.2.14-extended-bin_20100301.zip',
+      ],
       sha1sum  => '4576dfeb812450fce5bb22b915985ec696ea699f',
       arch_re  => qr/^MSWin32-x64-multi-thread$/,
       os_re    => qr/^MSWin32$/,
@@ -58,10 +67,22 @@ my $source_packs = [
         ]
     },
     members     => [
+      {
+        pack => 'zlib',
+        dirname => 'zlib-1.2.5',
+        url => [
+          'http://zlib.net/zlib-1.2.5.tar.gz',
+          'http://froggs.de/libz/zlib-1.2.5.tar.gz',
+        ],
+        sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+      },
       {
         pack => 'SDL',
         dirname => 'SDL-1.2.14',
-        url => 'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+        url => [
+          'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+          'http://froggs.de/libsdl/SDL-1.2.14.tar.gz',
+        ],
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
@@ -70,62 +91,89 @@ my $source_packs = [
       {
         pack => 'jpeg',
         dirname => 'jpeg-8a',
-        url => 'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+        url => [
+          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+        ],
         sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
         patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
         dirname => 'tiff-3.9.1',
-        url => 'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        url => [
+          'http://froggs.de/libtiff/tiff-3.9.1.tar.gz',
+          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        ],
         sha1sum  => '675ad1977023a89201b80cd5cd4abadea7ba0897',
         patches => [ ],
       },
       {
         pack => 'libpng',
         dirname => 'libpng-1.4.1',
-        url => 'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+        url => [
+          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
+        ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
       },
       {
         pack => 'SDL_image',
         dirname => 'SDL_image-1.2.10',
-        url => 'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
+        ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
         patches => [ ],
       },
       {
         pack => 'SDL_mixer',
         dirname => 'SDL_mixer-1.2.11',
-        url => 'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+          'http://froggs.de/libsdl/SDL_mixer-1.2.11.tar.gz',
+        ],
         sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
         patches => [ ],
       },
       {
         pack => 'SDL_ttf',
         dirname => 'SDL_ttf-2.0.10',
-        url => 'http://www.libsdl.org/tmp/SDL_ttf/release/SDL_ttf-2.0.10.tar.gz',
+        url => [
+          'http://www.libsdl.org/tmp/SDL_ttf/release/SDL_ttf-2.0.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_ttf-2.0.10.tar.gz',
+        ],
         sha1sum  => '98f6518ec71d94b8ad303a197445e0991850b887',
         patches => [ ],
       },
       {
         pack => 'SDL_net',
         dirname => 'SDL_net-1.2.7',
-        url => 'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+          'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
+        ],
         sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
         patches => [ ],
       },
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
-        url => 'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+        url => [
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+          'http://froggs.de/libsdl/SDL_gfx-2.0.20.tar.gz',
+        ],
         sha1sum  => '077f7e64376c50a424ef11a27de2aea83bda3f78',
         patches => [ ],
       },
       {
         pack => 'SDL_Pango',
         dirname => 'SDL_Pango-0.1.2',
-        url => 'http://downloads.sourceforge.net/sdlpango/SDL_Pango-0.1.2.tar.gz',
+        url => [
+          'http://downloads.sourceforge.net/sdlpango/SDL_Pango-0.1.2.tar.gz',
+          'http://froggs.de/libsdl/SDL_Pango-0.1.2.tar.gz',
+        ],
         sha1sum  => 'c30f2941d476d9362850a150d29cb4a93730af68',
         patches => [ 'SDL_Pango-0.1.2-API-adds.patch' ],
       },
@@ -146,64 +194,100 @@ my $source_packs = [
       {
         pack => 'SDL',
         dirname => 'SDL-1.2.14',
-        url => 'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+        url => [
+          'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+          'http://froggs.de/libsdl/SDL-1.2.14.tar.gz',
+        ],
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
         ],
       },
+      {
+        pack => 'zlib',
+        dirname => 'zlib-1.2.5',
+        url => [
+          'http://zlib.net/zlib-1.2.5.tar.gz',
+          'http://froggs.de/libz/zlib-1.2.5.tar.gz',
+        ],
+        sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+      },
       {
         pack => 'jpeg',
         dirname => 'jpeg-8a',
-        url => 'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+        url => [
+          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+        ],
         sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
         patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
         dirname => 'tiff-3.9.1',
-        url => 'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        url => [
+          'http://froggs.de/libtiff/tiff-3.9.1.tar.gz',
+          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        ],
         sha1sum  => '675ad1977023a89201b80cd5cd4abadea7ba0897',
         patches => [ ],
       },
       {
         pack => 'libpng',
         dirname => 'libpng-1.4.1',
-        url => 'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+        url => [
+          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
+        ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
       },
       {
         pack => 'SDL_image',
         dirname => 'SDL_image-1.2.10',
-        url => 'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
+        ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
         patches => [ ],
       },
       {
         pack => 'SDL_mixer',
         dirname => 'SDL_mixer-1.2.11',
-        url => 'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+          'http://froggs.de/libsdl/SDL_mixer-1.2.11.tar.gz',
+        ],
         sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
         patches => [ ],
       },
       {
         pack => 'SDL_ttf',
         dirname => 'SDL_ttf-2.0.9',
-        url => 'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.9.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.9.tar.gz',
+          'http://froggs.de/libsdl/SDL_ttf-2.0.9.tar.gz',
+        ],
         sha1sum  => '6bc3618b08ddbbf565fe8f63f624782c15e1cef2',
         patches => [ ],
       },
       {
         pack => 'SDL_net',
         dirname => 'SDL_net-1.2.7',
-        url => 'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+          'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
+        ],
         sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
         patches => [ ],
       },
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
-        url => 'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+        url => [
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+          'http://froggs.de/libsdl/SDL_gfx-2.0.20.tar.gz',
+        ],
         sha1sum  => '077f7e64376c50a424ef11a27de2aea83bda3f78',
         patches => [ ],
       },
@@ -216,46 +300,63 @@ my $source_packs = [
     prereqs => {
         libs => [
           'pthread', # SDL
-          'tiff',    # SDL_image
         ]
     },
     members     => [
       {
         pack => 'zlib',
         dirname => 'zlib-1.2.5',
-        url => 'http://zlib.net/zlib-1.2.5.tar.gz',
+        url => [
+          'http://zlib.net/zlib-1.2.5.tar.gz',
+          'http://froggs.de/libz/zlib-1.2.5.tar.gz',
+        ],
         sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
       },
       {
         pack => 'jpeg',
         dirname => 'jpeg-8a',
-        url => 'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+        url => [
+          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+        ],
         sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
         patches => [ 'jpeg-8a_cygwin.patch' ],
       },
       {
         pack => 'tiff',
         dirname => 'tiff-3.9.1',
-        url => 'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        url => [
+          'http://froggs.de/libtiff/tiff-3.9.1.tar.gz',
+          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        ],
         sha1sum  => '675ad1977023a89201b80cd5cd4abadea7ba0897',
         patches => [ ],
       },
       {
         pack => 'libpng',
         dirname => 'libpng-1.4.1',
-        url => 'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+        url => [
+          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
+        ],
         sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
       },
       {
         pack => 'freetype',
         dirname => 'freetype-2.3.12',
-        url => 'http://mirror.lihnidos.org/GNU/savannah/freetype/freetype-2.3.12.tar.gz',
+        url => [
+          'http://mirror.lihnidos.org/GNU/savannah/freetype/freetype-2.3.12.tar.gz',
+          'http://froggs.de/libfreetype/freetype-2.3.12.tar.gz',
+        ],
         sha1sum  => '0082ec5e99fec5a1c6d89b321a7e2f201542e4b3',
       },
       {
         pack => 'SDL',
         dirname => 'SDL-1.2.14',
-        url => 'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+        url => [
+          'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+          'http://froggs.de/libsdl/SDL-1.2.14.tar.gz',
+        ],
         sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
         patches => [
           'test1.patch',
@@ -264,35 +365,50 @@ my $source_packs = [
       {
         pack => 'SDL_image',
         dirname => 'SDL_image-1.2.10',
-        url => 'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
+        ],
         sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
         patches => [ ],
       },
       {
         pack => 'SDL_mixer',
         dirname => 'SDL_mixer-1.2.11',
-        url => 'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+          'http://froggs.de/libsdl/SDL_mixer-1.2.11.tar.gz',
+        ],
         sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
         patches => [ ],
       },
       {
         pack => 'SDL_ttf',
         dirname => 'SDL_ttf-2.0.9',
-        url => 'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.9.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_ttf/release/SDL_ttf-2.0.9.tar.gz',
+          'http://froggs.de/libsdl/SDL_ttf-2.0.9.tar.gz',
+        ],
         sha1sum  => '6bc3618b08ddbbf565fe8f63f624782c15e1cef2',
         patches => [ ],
       },
       {
         pack => 'SDL_net',
         dirname => 'SDL_net-1.2.7',
-        url => 'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+        url => [
+          'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+          'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
+        ],
         sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
         patches => [ ],
       },
       {
         pack => 'SDL_gfx',
         dirname => 'SDL_gfx-2.0.20',
-        url => 'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+        url => [
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+          'http://froggs.de/libsdl/SDL_gfx-2.0.20.tar.gz',
+        ],
         sha1sum  => '077f7e64376c50a424ef11a27de2aea83bda3f78',
         patches => [ ],
       },
@@ -345,50 +461,54 @@ sub check_src_build
   my @good = ();
   foreach my $p (@{$source_packs}) {
     $p->{buildtype} = 'build_from_sources';
-	push @good, $p if check_prereqs($p);
+    push @good, $p if check_prereqs($p);
   }
   return \@good;
 }
 
 sub check_prereqs_libs {
   my @libs = @_;
+  my $ret  = 1;
 
-  for my $lib (@libs) {
+  foreach my $lib (@libs) {
     my $found_lib          = '';
     my $found_inc          = '';
     my $inc_lib_candidates = {
       '/usr/local/include' => '/usr/local/lib',
       '/usr/include'       => '/usr/lib',
     };
-	my $header_map         = {
-	  'z'    => 'zlib',
-	  'jpeg' => 'jpeglib',
-	};
-	my $header             = (defined $header_map->{$lib}) ? $header_map->{$lib} : $lib;
+    my $header_map         = {
+      'z'    => 'zlib',
+      'jpeg' => 'jpeglib',
+    };
+    my $header             = (defined $header_map->{$lib}) ? $header_map->{$lib} : $lib;
 
     foreach (keys %$inc_lib_candidates) {
-	  my $ld = $inc_lib_candidates->{$_};
+      my $ld = $inc_lib_candidates->{$_};
       next unless -d $_ && -d $ld;
       ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.\Q$Config{dlext}\E[\d\.]*$/);
       ($found_inc) = find_file($_,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
       last if $found_lib && $found_inc;
     }
-	
-	if($found_lib && $found_inc) {
-      return 1;
+
+    if($found_lib && $found_inc) {
+      $ret &= 1;
     }
     else {
       print "WARNING: required lib(-dev) '$lib' not found, disabling affected option\n";
+      $ret = 0;
     }
   }
+
+  return $ret;
 }
 
 sub check_prereqs {
   my $bp  = shift;
   my $ret = 1;
-  
+
   $ret &= check_prereqs_libs(@{$bp->{prereqs}->{libs}}) if defined $bp->{prereqs}->{libs};
-  
+
   return $ret;
 }
 
